@@ -6,18 +6,9 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -25,7 +16,7 @@
 #define DIGIKAM_CONFIG_H
 
 /* Define to 1 if you have KDEPIM shared library installed */
-#define HAVE_AKONADICONTACT 1
+/* #undef HAVE_AKONADICONTACT */
 
 /* Define to 1 if an external liblqr-1 shared library have been found */
 #define HAVE_LIBLQR_1 1
@@ -36,6 +27,9 @@
 /* Define to 1 if an external KIO shared library have been found */
 #define HAVE_KIO 1
 
+/* Define to 1 if an external Sonnet shared library have been found */
+#define HAVE_SONNET 1
+
 /* Define to 1 if an external Ksane shared library have been found */
 #define HAVE_KSANE 1
 
@@ -45,12 +39,12 @@
 /* Define to 1 if an external Eigen3 shared library have been found */
 #define HAVE_EIGEN3 1
 
-/* Define to 1 if an external HEIF shared library have been found */
-#define HAVE_HEIF 1
-
 /* Define to 1 if an external x265 shared library have been found */
 #define HAVE_X265 1
 
+/* Define to 1 if an external Heif shared library have been found */
+#define HAVE_HEIF 1
+
 /* The Eigen3 version string, if found, or an empty string otherwise */
 #define EIGEN3_VERSION_STRING "3.3.9"
 
@@ -111,7 +105,7 @@
 /* Define to 1 if changing application styles is supported */
 /* #undef HAVE_APPSTYLE_SUPPORT */
 
-/* Define to 1 if system use QtWebEngine instead of QWebKit */
+/* Define to 1 if system use QtWebEngine */
 #define HAVE_QWEBENGINE 1
 
 /* Define to 1 if system use QtXmlPatterns */
@@ -126,8 +120,8 @@
 #define LIBEXEC_INSTALL_DIR "/usr/local/libexec"
 
 /*
-  Disable indeep warnings from Visual Studio C++ 2008 (9.0)
-*/
+ * Disable indeep warnings from Visual Studio C++
+ */
 #if defined(_MSC_VER)
 // To disable warnings about no suitable definition provided for explicit template instantiation request.
 #pragma warning(disable : 4661)
@@ -135,6 +129,8 @@
 #pragma warning(disable : 4996)
 // To disable warnings about qualifier applied to reference type ignored.
 #pragma warning(disable : 4181)
+// To disable warnings about 'storage-class-keyword' no longer supported as storage class.
+#pragma warning(disable : 5033)
 #endif
 
 #endif // DIGIKAM_CONFIG_H
